-- Performance Data Warehouse example 
CREATE DATABASE PerfDB
ON (NAME = PerfDB_dat,
    FILENAME = 'C:\PerfDB_dat.mdf', SIZE = 100, FILEGROWTH = 10)
LOG ON (NAME = PerfDB_log,
    FILENAME = 'C:\PerfDB_log.ldf', SIZE = 10, FILEGROWTH = 10);

USE PerfDB;
CREATE TABLE ExecQueryStats(
    current_datetime DATETIME,
    sql_text VARCHAR(8000),
    plan_generation_num BIGINT,
    plan_handle VARBINARY(64),
    creation_time DATETIME,
    last_execution_time DATETIME,
    execution_count BIGINT,
    total_worker_time BIGINT,
    last_worker_time BIGINT,
    min_worker_time BIGINT,
    max_worker_time BIGINT,
    total_physical_reads BIGINT,
    last_physical_reads BIGINT,
    min_physical_reads BIGINT,
    max_physical_reads BIGINT,
    total_logical_writes BIGINT,
    last_logical_writes BIGINT,
    min_logical_writes BIGINT,
    max_logical_writes BIGINT,
    total_logical_reads BIGINT,
    last_logical_reads BIGINT,
    min_logical_reads BIGINT,
    max_logical_reads BIGINT,
    total_clr_time BIGINT,
    last_clr_time BIGINT,
    min_clr_time BIGINT,
    max_clr_time BIGINT,
    total_elapsed_time BIGINT,
    last_elapsed_time BIGINT,
    min_elapsed_time BIGINT,
    max_elapsed_time BIGINT
);

USE PerfDB;
INSERT ExecQueryStats
    SELECT TOP 10 GETDATE(),
        (SELECT SUBSTRING(text, statement_start_offset/2,
            (CASE WHEN statement_end_offset = <;$MI>1
                THEN LEN(CONVERT(nvarchar(max), text)) * 2
            ELSE statement_end_offset
            END <;$MI> statement_start_offset)/2 + 1)
        FROM sys.dm_exec_sql_text(sql_handle)),
        plan_generation_num,
        plan_handle,
        creation_time,
        last_execution_time,
        execution_count,
        total_worker_time,
        last_worker_time,
        min_worker_time,
        max_worker_time,
        total_physical_reads,
        last_physical_reads,
        min_physical_reads,
        max_physical_reads,
        total_logical_writes,
        last_logical_writes,
        min_logical_writes,
        max_logical_writes,
        total_logical_reads,
        last_logical_reads,
        min_logical_reads,
        max_logical_reads,
        total_clr_time,
        last_clr_time,
        min_clr_time,
        max_clr_time,
        total_elapsed_time,
        last_elapsed_time,
        min_elapsed_time,
        max_elapsed_time
    FROM sys.dm_exec_query_stats AS eqs
    ORDER BY eqs.last_worker_time DESC;
